| createConfigurationFile | R Documentation |
Generic function for creating additional configuration file for the archive with test
createConfigurationFile(object, output)
## S4 method for signature 'AssessmentTest'
createConfigurationFile(object, output)
## S4 method for signature 'AssessmentTestOpenOlat'
createConfigurationFile(object, output)
object |
an instance of the S4 object AssessmentTest |
output |
string, a folder to store an xml configuration files |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.