| createCourseGroup | R Documentation |
This method creates a group in a course on the Learning Management System (LMS). If no LMS connection object is provided, it attempts to guess the connection using default settings (e.g., environment variables). If the connection cannot be established, an error is thrown.
This method creates a learning group in an LMS Opal course using OPAL's
GroupVO XML representation. The group name must be unique within the
course. invitationEnabled controls whether new group members receive an
invitation that has to be accepted; signoutEnabled controls whether members
may leave the group themselves.
createCourseGroup(object, course_id, name, ...)
## S4 method for signature 'missing'
createCourseGroup(object, course_id, name, ...)
## S4 method for signature 'Opal'
createCourseGroup(
object,
course_id,
name,
description = "",
minParticipants = 0,
maxParticipants = 0,
invitationEnabled = TRUE,
signoutEnabled = TRUE
)
object |
An S4 object of class Opal that represents a connection to the LMS. |
course_id |
A character vector of length one specifying the course resource ID. Note that this is not the course ID shown in the URL, but a longer identifier available via the "Show more information" option within the course. |
name |
A character vector of length one with the group name. |
... |
Additional arguments to be passed to the method, if applicable. |
description |
A character vector of length one with the group description. Defaults to an empty string. |
minParticipants |
A numeric value with the minimum number of
participants. Defaults to |
maxParticipants |
A numeric value with the maximum number of
participants. Defaults to |
invitationEnabled |
A boolean value. If |
signoutEnabled |
A boolean value. If |
A data frame with the created group attributes.
A one-row data frame with the created group attributes, or NULL
when OPAL rejects the request.
group <- createCourseGroup("89068111333293", "Topic 5")
group <- createCourseGroup(
"89068111333293",
"Topic 5",
description = "Group for topic 5",
minParticipants = 1,
maxParticipants = 1,
invitationEnabled = FALSE,
signoutEnabled = FALSE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.