createZip-methods: Create an Zip archive of QTI test

createZipR Documentation

Create an Zip archive of QTI test

Description

Generic function for creating zip archive with set of XML documents of specification the test following the QTI schema v2.1

Usage

createZip(object, input, output, file_name, zip_only)

## S4 method for signature 'AssessmentTest'
createZip(object, input, output, file_name, zip_only)

## S4 method for signature 'AssessmentTestOpal'
createZip(object, input, output, file_name, zip_only)

Arguments

object

an instance of the S4 object AssessmentTest or AssessmentTestOpal

input

string, optional; a source folder with xml files

output

string, optional; a folder to store zip and xml files; working directory by default

file_name

string, optional; file name of zip archive

zip_only

boolean, optional; if TRUE, returns only the zip file. If FALSE, returns the zip, XML, and download files.


rqti documentation built on Sept. 21, 2026, 5:08 p.m.