Skip to contents

Helper function for using tasks written in the exams Rmd format inside rqti sections. The function converts the given Rmd file with exams::exams2qti21() and returns the path to the generated XML file.

Usage

exams_task(path, title = NULL)

Arguments

path

Character string. Path to an Rmd file written in the exams format.

title

Character string or NULL. Optional title passed to exams::exams2qti21() via the ititle argument.

Value

Character string. Path to the QTI 2.1 XML file generated by exams::exams2qti21() in a temporary directory.

Details

This function is mainly useful when exams tasks need to be combined with native rqti tasks in one section, for example: section(exams_task(path_to_file, title = "Exams task")).

Examples

if (FALSE) { # interactive()
path <- system.file("exams", "example.Rmd", package = "rqti")
section(exams_task(path, title = "Exams task"))
}