german_grading: German grading scale

View source: R/response_processing.R

german_gradingR Documentation

German grading scale

Description

A helper function that returns a named numeric vector representing a common German grading scheme. The names correspond to grades and the values define the minimum proportion of points required to achieve the respective grade.

Usage

german_grading()

Value

A named numeric vector with grades as names and minimum score proportions as values.

Examples

german_grading()



rqti documentation built on Sept. 21, 2026, 5:08 p.m.