| getGroupUsers | R Documentation |
This method retrieves users from a group on the Learning Management System (LMS) by its group id. It returns a data frame with all accessible attributes of the group members. If no LMS connection object is provided, it attempts to guess the connection using default settings (e.g., environment variables). If the connection cannot be established, an error is thrown.
This method retrieves users from a group on LMS Opal by its group id. It returns a data frame with user attributes obtained from the LMS, including user id, login, first name, last name, email, and additional properties (e.g., status). If no Opal connection object is provided, it attempts to guess the connection using default settings (e.g., environment variables). If the connection cannot be established, an error is thrown.
getGroupUsers(object, group_id)
## S4 method for signature 'missing'
getGroupUsers(object, group_id)
## S4 method for signature 'Opal'
getGroupUsers(object, group_id)
object |
An S4 object of class Opal that represents a connection to the LMS. |
group_id |
A character vector specifying the group id. |
A data frame with all accessible attributes of the group members.
A data frame with group users and their attributes. Each row represents a user and may include the following columns:
Unique user id.
User login name.
User first name.
User last name.
User email address.
User status (e.g., STATUS_ACTIVE).
groups <- getGroupUsers("89068111333293")
users <- getGroupUsers("89068111333293")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.