isUserLoggedIn-methods: Check if User is Logged in LMS

isUserLoggedInR Documentation

Check if User is Logged in LMS

Description

This method checks whether a user is logged into an LMS (Learning Management System) by sending a request to the LMS server and evaluating the response.

This method checks whether a user is logged into an LMS Opal by sending a request to the LMS server and evaluating the response.

Usage

isUserLoggedIn(object)

## S4 method for signature 'Opal'
isUserLoggedIn(object)

Arguments

object

An S4 object of class Opal that represents a connection to the LMS.

Value

A logical value (TRUE if the user is logged in, FALSE otherwise).

A logical value (TRUE if the user is logged in, FALSE otherwise).


rqti documentation built on Feb. 23, 2026, 5:06 p.m.