publishCourse-Opal-method: Publish a course on LMS Opal

publishCourse,Opal-methodR Documentation

Publish a course on LMS Opal

Description

Publish a course on LMS Opal

Usage

## S4 method for signature 'Opal'
publishCourse(object, course_id)

Arguments

object

An S4 object of class Opal that represents a connection to the LMS.

course_id

A character string with course id in the LMS.

Value

Status code of the HTTP request.


rqti documentation built on Feb. 23, 2026, 5:06 p.m.