qtijs_pkg_path: Shortcut for the qtijs path of the rqti package local...

View source: R/knit_functions.R

qtijs_pkg_pathR Documentation

Shortcut for the qtijs path of the rqti package local installation.

Description

Shortcut for the qtijs path of the rqti package local installation.

Usage

qtijs_pkg_path()

Examples

  qtijs_pkg_path()

rqti documentation built on Feb. 23, 2026, 5:06 p.m.