View source: R/knit_functions.R
| render_xml | R Documentation |
Uses qtijs to render a single xml file in the RStudio viewer pane with a local server.
render_xml(input, qtijs_path = qtijs_pkg_path())
input |
The path to the input Rmd/md/xml document or an AssessmentItem, AssessmentTest, AssessmentTestOpal, AssessmentSection object. |
qtijs_path |
The path to the qtijs renderer (qti.js), which will be started with servr::httw and to which xml files will be copied. Default is the QTIJS folder in the R package rqti local installation via the helper qtijs_pkg_path(). |
nothing, has side effects
file <- system.file("exercises/sc1d.xml", package = 'rqti')
render_qtijs(file)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.