rqti-package: rqti: Create Tests According to QTI 2.1 Standard

rqti-packageR Documentation

rqti: Create Tests According to QTI 2.1 Standard

Description

Create tests and tasks compliant with the Question & Test Interoperability (QTI) information model version 2.1. Input sources are Rmd/md description files or S4-class objects. Output formats include standalone zip or xml files. Supports the generation of basic task types (single and multiple choice, order, pair association, matching tables, filling gaps and essay) and provides a comprehensive set of attributes for customizing tests.

Author(s)

Maintainer: Andrey Shevandrin shevandrin@gmail.com (ORCID) [copyright holder]

Authors:

Other contributors:

See Also

Useful links:


rqti documentation built on Sept. 21, 2026, 5:08 p.m.