View source: R/knit_functions.R
| start_server | R Documentation |
This function starts an http server with the qtijs renderer. The renderer performs the conversion of qti.xml into HTML.
start_server(qtijs_path = qtijs_pkg_path(), daemon = T)
qtijs_path |
The path to the qtijs renderer (qti.js), which will be started with servr::httw and to which xml files will be copied. Default is the QTIJS folder in the R package rqti local installation via the helper qtijs_pkg_path(). |
daemon |
This parameter is forwarded to |
The server has to be started manually by the user, otherwise the Knit-Button will not work. The Knit-Button starts a new session and invoking a server there does not work. You can automatically start the server via an .RProfile file on start up.
The URL string of the qtijs server.
## Not run:
start_server()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.