| upload2opal | R Documentation |
Function upload2opal() takes full prepared zip archive of QTI-test or
QTI-task and uploads it to the OPAL.
upload2opal(
test,
display_name = NULL,
access = 4,
overwrite = TRUE,
endpoint = NULL,
open_in_browser = TRUE,
as_survey = FALSE,
api_user = NULL
)
test |
A length one character vector of AssessmentTest, AssessmentTestOpal or AssessmentItem objects, Rmd/md or XML files; required. |
display_name |
A length-one character vector naming the file in OPAL; by default, this is the file name without extension; optional. |
access |
An integer value, optional; it controls publication status, where 1 - only those responsible for this learning resource; 2 - responsible and other authors; 3 - all registered users; 4 - registered users and guests. Default is 4. |
overwrite |
A boolean value; if |
endpoint |
A string containing the OPAL LMS endpoint; by default, it is read from
environment variable |
open_in_browser |
A boolean value, optional; controls whether to open
a URL in the default browser. Default is |
as_survey |
A boolean value, optional; controls the resource type (test
or survey). Default is |
api_user |
A character value of the username in the OPAL. |
A list with the key, display name, and URL of the resource in Opal.
file <- system.file(
"rmarkdown/templates/singlechoice-simple/skeleton/skeleton.Rmd",
package='rqti'
)
upload2opal(file, "task 1", open_in_browser = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.