Abstract class Gap is not meant to be instantiated directly; instead, it
serves as a base for derived classes such as NumericGap, TextGap,
TextGapOpal and InlineChoice.
Slots
response_identifierA character value representing an identifier for the answer. By default, it is generated as 'id_gap_dddd', where dddd represents random digits.
pointsA numeric value, optional, representing the number of points for this gap. Default is
1.placeholderA character value, optional, used to place helpful text in the text input field in the content delivery engine.
expected_lengthA numeric value, optional, used to set the size of the text input field in the content delivery engine.
See also
NumericGap, TextGap, TextGapOpal and InlineChoice.