| addGroupUser | R Documentation |
This method adds a user to a group on the Learning Management System (LMS). If no LMS connection object is provided, it attempts to guess the connection using default settings (e.g., environment variables). If the connection cannot be established, an error is thrown.
This method adds a user to a learning group in LMS Opal by group id and user id.
addGroupUser(object, group_id, user_id)
## S4 method for signature 'missing'
addGroupUser(object, group_id, user_id)
## S4 method for signature 'Opal'
addGroupUser(object, group_id, user_id)
object |
An S4 object of class Opal that represents a connection to the LMS. |
group_id |
A character vector of length one specifying the group ID. |
user_id |
A character vector of length one specifying the user ID. |
Status code of the HTTP request.
Status code 200 if the user was added successfully, or NULL when
OPAL rejects the request.
addGroupUser("442662912", "196610")
addGroupUser("442662912", "196610")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.