Create a configuration file for QTI test
Source:R/AssessmentTest.R, R/AssessmentTestOpenOlat.R
createConfigurationFile-methods.RdGeneric function for creating additional configuration file for the archive with test
Usage
createConfigurationFile(object, output)
# S4 method for class 'AssessmentTest'
createConfigurationFile(object, output)
# S4 method for class 'AssessmentTestOpenOlat'
createConfigurationFile(object, output)Arguments
- object
an instance of the S4 object AssessmentTest
- output
string, a folder to store an xml configuration files