View source: R/response_processing.R
| german_grading | R Documentation |
A helper function that returns a named numeric vector representing a common German grading scheme. The names correspond to grades and the values define the minimum proportion of points required to achieve the respective grade.
german_grading()
A named numeric vector with grades as names and minimum score proportions as values.
german_grading()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.