A helper function that returns a named numeric vector representing a common German grading scheme. The names correspond to grades and the values define the minimum proportion of points required to achieve the respective grade.
A helper function that returns a named numeric vector representing a common German grading scheme. The names correspond to grades and the values define the minimum proportion of points required to achieve the respective grade.