This helper function initializes an Opal object, a subclass of LMS,
representing a connection to the Opal Learning Management System (LMS).
Arguments
- api_user
A character string specifying the API username.
- endpoint
A character string specifying the API endpoint for the LMS.
- credential_id
An optional name for the credential set. By default, rqti continues to use the legacy
rqtiopalservice. Supply an ID to use a separate password for another OPAL installation.