View source: R/knit_functions.R
| prepare_renderer | R Documentation |
Starts server for qtijs, returns path of qtijs and the url of the server.
prepare_renderer(qtijs_path = qtijs_pkg_path())
qtijs_path |
The path to the qtijs renderer (qti.js), which will be started with servr::httw and to which xml files will be copied. Default is the QTIJS folder in the R package rqti local installation via the helper qtijs_pkg_path(). |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.