Learn R Programming

rqti (version 1.1.0)

qtijs_pkg_path: Shortcut for the qtijs path of the rqti package local installation.

Description

Shortcut for the qtijs path of the rqti package local installation.

Usage

qtijs_pkg_path()

Arguments

Examples

Run this code
  qtijs_pkg_path()

Run the code above in your browser using DataLab