Requires a running qtijs server, which can be started with start_server().
The preview is automatically loaded into the RStudio viewer pane if run in
RStudio. Alternatively you can just open the browser at the corresponding
local server url which is displayed after rendering is finished. Since the
function is supposed to be called via the Knit-Button in RStudio, it defaults
to the RStudio viewer pane.
Customize knit function in the Rmd file using the following YAML setting
after the word knit knit: rqti::render_qtijs.