Uses qtijs to render a single xml file in the RStudio viewer pane with a
local server.
Usage
render_xml(input, qtijs_path = qtijs_pkg_path())
Value
nothing, has side effects
Arguments
input
The path to the input Rmd/md/xml document or an
AssessmentItem, AssessmentTest, AssessmentTestOpal,
AssessmentSection object.
qtijs_path
The path to the qtijs renderer (qti.js), which will be
started with servr::httw and to which xml files will be copied. Default is
the QTIJS folder in the R package rqti local installation via the helper
qtijs_pkg_path().