Uses qtijs to render a zipped qti archive in the RStudio viewer pane with a local server.
render_zip(input, qtijs_path = qtijs_pkg_path())nothing, has side effects
The path to the input Rmd/md/xml document or an AssessmentItem, AssessmentTest, AssessmentTestOpal, AssessmentSection object.
The path to the qtijs renderer (qti.js), which will be started with servr::httw and to which xml files will be copied. Default is the QTIJS folder in the R package rqti local installation via the helper qtijs_pkg_path().