| rqti-package | R Documentation |
Create tests and tasks compliant with the Question & Test Interoperability (QTI) information model version 2.1. Input sources are Rmd/md description files or S4-class objects. Output formats include standalone zip or xml files. Supports the generation of basic task types (single and multiple choice, order, pair association, matching tables, filling gaps and essay) and provides a comprehensive set of attributes for customizing tests.
Maintainer: Andrey Shevandrin shevandrin@gmail.com (ORCID) [copyright holder]
Authors:
Johannes Titz johannes@titz.science (ORCID) [copyright holder]
Other contributors:
Petr Bondarenko bondarenko.volsu@gmail.com (ORCID) [contributor]
Ivonne Ojeda yulieth9109@gmail.com [contributor]
Brian Mottershead (Author of QTIJS library) [copyright holder]
Stiftung für Innovation in der Hochschullehre [funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.