Learn R Programming

rqti (version 1.1.0)

start_server: Start qtijs renderer as a local server.

Description

This function starts an http server with the qtijs renderer. The renderer performs the conversion of qti.xml into HTML.

Usage

start_server(qtijs_path = qtijs_pkg_path(), daemon = T)

Value

The URL string of the qtijs server.

Arguments

qtijs_path

The path to the qtijs renderer (qti.js), which will be started with servr::httw and to which xml files will be copied. Default is the QTIJS folder in the R package rqti local installation via the helper qtijs_pkg_path().

daemon

This parameter is forwarded to servr::httw and should always be TRUE (the default). FALSE is only used for testing purposes when called via callr::bg()

Details

The server has to be started manually by the user, otherwise the Knit-Button will not work. The Knit-Button starts a new session and invoking a server there does not work. You can automatically start the server via an .RProfile file on start up.

Examples

Run this code
if (FALSE) {
start_server()
}

Run the code above in your browser using DataLab